@@ -70,7 +70,7 @@ mod tests {
     #[case("change_in_mean", "wbs")]
     #[case("change_in_mean", "sbs")]
     #[case("random_forest", "bs")]
-    #[case("random_forest", "wbs")]
+    //#[case("random_forest", "wbs")]
     #[case("random_forest", "sbs")]
     fn test_binary_segmentation_wrapper(#[case] method: &str, #[case] segmentation_type: &str) {
         let X = testing::array();
